==> views_cumulative_field-8.x-1.3.tar.gz: views_cumulative_field/src/Plugin/views/field/CumulativeField.php <==
<?php

namespace Drupal\views_cumulative_field\Plugin\views\field;

use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\PluralTranslatableMarkup;
use Drupal\views\Plugin\views\field\NumericField;
use Drupal\views\ResultRow;

/**
 * @file
 * Defines Drupal\views_cumulative_field\Plugin\views\field\CumulativeField.
 */

/**
 * Field handler to flag the node type.
 *
 * @ingroup views_field_handlers
 * @ViewsField("field_cumulative_field")
 */
class CumulativeField extends NumericField {

  private $counter = 0;

  /**
   * Sets the initial Cumulative Field data at zero.
   */
  public function query() {
    $this->additional_fields['cumulative_field_data'] = 0;
  }

  /**
   * {@inheritdoc}
   */
  protected function defineOptions() {
    $options = parent::defineOptions();
    $options['data_field'] = array('default' => NULL);
    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);
    $form['data_field'] = array(
      '#type' => 'radios',
      '#title' => t('Data Field'),
      '#options' => $this->displayHandler->getFieldLabels(),
      '#default_value' => $this->options['data_field'],
      '#description' => t('Select the field for which to calculate the cumulative value.'),
      '#weight' => -10,
    );
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function getValue(ResultRow $values, $field = NULL) {
    parent::getValue($values, $field);

    $field = $this->options['data_field'];
    $this->additional_fields['cumulative_field_data']
      = $values->_entity->get($field)->value
      + $this->additional_fields['cumulative_field_data'];
    $value = $this->additional_fields['cumulative_field_data'];

    // A control for modules that modify the row count.
    $this->counter++;
    if($this->counter == $this->view->total_rows){
      $this->additional_fields['cumulative_field_data'] = 0;
    }

    return $value;
  }

}

==> views_cumulative_field-8.x-1.4.tar.gz: views_cumulative_field/src/Plugin/views/field/CumulativeField.php <==
<?php

namespace Drupal\views_cumulative_field\Plugin\views\field;

use Drupal\Core\Form\FormStateInterface;
use Drupal\views\Plugin\views\field\NumericField;
use Drupal\views\ResultRow;

/**
 * @file
 * Defines Drupal\views_cumulative_field\Plugin\views\field\CumulativeField.
 */

/**
 * Field handler to flag the node type.
 *
 * @ingroup views_field_handlers
 * @ViewsField("field_cumulative_field")
 */
class CumulativeField extends NumericField {

  private $counter = 0;

  /**
   * Sets the initial Cumulative Field data at zero.
   */
  public function query() {
    $this->additional_fields['cumulative_field_data'] = 0;
  }

  /**
   * {@inheritdoc}
   */
  protected function defineOptions() {
    $options = parent::defineOptions();
    $options['data_field'] = ['default' => NULL];
    return $options;
  }

  /**
   * {@inheritdoc}
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) {
    parent::buildOptionsForm($form, $form_state);
    $form['data_field'] = [
      '#type' => 'radios',
      '#title' => t('Data Field'),
      '#options' => $this->displayHandler->getFieldLabels(),
      '#default_value' => $this->options['data_field'],
      '#description' => t('Select the field for which to calculate the cumulative value.'),
      '#weight' => -10,
    ];
    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function getValue(ResultRow $values, $field = NULL) {
    parent::getValue($values, $field);

    $field = $this->options['data_field'];
    $this->additional_fields['cumulative_field_data']
      = $values->_entity->get($field)->value
      + $this->additional_fields['cumulative_field_data'];
    $value = $this->additional_fields['cumulative_field_data'];

    // A control for modules that modify the row count.
    $this->counter++;
    if ($this->counter == $this->view->total_rows) {
      $this->additional_fields['cumulative_field_data'] = 0;
    }

    return $value;
  }

}
